========
Download
========

Mini-AMF is released under the :doc:`MIT license <../license>`. For
installation instructions, see the included :doc:`Installation Guide
<../install>`.


Latest Stable Release - |release|
=================================

+-----------------+--------------------------------------------------+
| **Gzipped Tar** | |t-pre|\ |release|\ |t-mid|\ |release|\ |t-post| |
+-----------------+--------------------------------------------------+

Git repository
==============

The `Git <https://git-scm.com/>`_ repository for Mini-AMF is
https://github.com/zackw/mini-amf.

The latest revision of Mini-AMF can be checked out with the
following command::

    git clone https://github.com/zackw/mini-amf.git

Older releases
==============

Older releases are `archived on PyPI`_.

.. _archived on PyPI: https://pypi.python.org/pypi/Mini-AMF


.. The following is a horrible kludge but it is better than having to
   remember to update this file for every release.
   See https://stackoverflow.com/questions/30920983 for explanation.

.. |t-pre| raw:: html

   <a href="https://files.pythonhosted.org/packages/source/M/Mini-AMF/Mini-AMF-

.. |t-mid| raw:: html

   .tar.gz">Mini-AMF-

.. |t-post| raw:: html

   .tar.gz</a>
